@@ -1,3 +1,4 @@
+from pyessv.accessors import copernicus_cordexp
 from pyessv.accessors import esdoc_cmip6
 from pyessv.accessors import wcrp_cmip6
 
@@ -5,6 +6,9 @@ from pyessv.accessors import wcrp_cmip6
 
 # Expose accessors mapped by authority.
 ACCESSORS = {
+	'copernicus': {
+		'cordexp': copernicus_cordexp
+	},	
 	'esdoc': {
 		'cmip6': esdoc_cmip6
 	},
